@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous   *
  *                  mode detection and handling.               *
  *                                                             *
- * Version:         1.0.9                                      *
+ * Version:         1.1.0                                      *
  *                                                             *
  * ----------------------------------------------------------- *
  *                                                             *
@@ -272,11 +272,24 @@ int ifStat( void )
 	 */
 	if( ( j & IFF_PROMISC ) && ( nullFlag == TRUE ) )
         {
-            printf( "%6s: PROMISC\n", class -> name );
-
-            if( ( writeLog( LOG_WARNING, "%4s: PROMISC\n", class -> name ) ) != 0 )
+            if( bFlag == TRUE )
             {
-                return (-1);
+                printf( "%6s: PROMISC (slave: %s)\n", class -> name, buf );
+
+                if( ( writeLog( LOG_WARNING, "%4s: PROMISC (slave: %s)\n", class -> name, buf ) ) != 0 )
+                {
+                    return (-1);
+                 }
+             }
+
+            else
+            {
+                printf( "%6s: PROMISC\n", class -> name );
+
+                if( ( writeLog( LOG_WARNING, "%4s: PROMISC\n", class -> name ) ) != 0 )
+                {
+                    return (-1);
+                 }
              }
          }
 
@@ -318,11 +331,24 @@ int ifStat( void )
                 return (-1); 
              }
 
-            printf( "%6s: PROMISC [*]\n", class -> name );
-
-            if( ( writeLog( LOG_WARNING, "%4s: PROMISC [*]\n", class -> name ) ) != 0 )
+            if( bFlag == TRUE )
             {
-                return (-1);
+                printf( "%6s: PROMISC [*] (slave: %s)\n", class -> name, buf );
+
+                if( ( writeLog( LOG_WARNING, "%4s: PROMISC [*] (slave: %s)\n", class -> name, buf ) ) != 0 )
+                {
+                    return (-1);
+                 }
+             }
+
+            else
+            {
+                printf( "%6s: PROMISC [*]\n", class -> name );
+
+                if( ( writeLog( LOG_WARNING, "%4s: PROMISC [*]\n", class -> name ) ) != 0 )
+                {
+                    return (-1);
+                 }
              }
          }
 
@@ -390,11 +416,26 @@ int ifStat( void )
 	 */
         else if( j & IFF_UP )
         {
-            printf( "%6s: normal\n", class -> name );
-
-            if( ( writeLog( LOG_INFO, "%4s: normal\n", class -> name ) ) != 0 )
+            if( bFlag == TRUE )
             {
-                return (-1);
+                /* printf( "%6s: normal\n", class -> name ); */
+                printf( "%6s: normal (slave: %s)\n", class -> name, buf );
+
+                /* if( ( writeLog( LOG_INFO, "%4s: normal\n", class -> name ) ) != 0 ) */
+                if( ( writeLog( LOG_INFO, "%4s: normal (slave: %s)\n", class -> name, buf ) ) != 0 )
+                {
+                    return (-1);
+                 }
+             }
+
+            else
+            {
+                printf( "%6s: normal\n", class -> name );
+
+                if( ( writeLog( LOG_INFO, "%4s: normal\n", class -> name ) ) != 0 )
+                {
+                    return (-1);
+                 }
              }
          }
 
@@ -403,11 +444,24 @@ int ifStat( void )
 	 */
         else
         {
-            printf( "%6s: *down*\n", class -> name );
-
-            if( ( writeLog( LOG_INFO, "%4s: *down*\n", class -> name ) ) != 0 )
+            if( bFlag == TRUE )
             {
-                return (-1);
+                printf( "%6s: *down* (slave: %s)\n", class -> name, buf );
+
+                if( ( writeLog( LOG_INFO, "%4s: *down* (slave: %s)\n", class -> name, buf ) ) != 0 )
+                {
+                    return (-1);
+                 }
+             }
+
+            else
+            {
+                printf( "%6s: *down*\n", class -> name );
+
+                if( ( writeLog( LOG_INFO, "%4s: *down*\n", class -> name ) ) != 0 )
+                {
+                    return (-1);
+                 }
              }
          }
 
